package com.dcs.hnyz.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.dcs.hnyz.domain.AlarmConfig;

/**
 * 告警配置管理Mapper接口
 * 
 * @author hmy
 * @date 2025-05-22
 */
public interface AlarmConfigMapper extends BaseMapper<AlarmConfig>
{
    /**
     * 查询告警配置管理
     * 
     * @param configId 告警配置管理主键
     * @return 告警配置管理
     */
    public AlarmConfig selectAlarmConfigByConfigId(Long configId);

    /**
     * 查询告警配置管理列表
     * 
     * @param alarmConfig 告警配置管理
     * @return 告警配置管理集合
     */
    public List<AlarmConfig> selectAlarmConfigList(AlarmConfig alarmConfig);

    /**
     * 新增告警配置管理
     * 
     * @param alarmConfig 告警配置管理
     * @return 结果
     */
    public int insertAlarmConfig(AlarmConfig alarmConfig);

    /**
     * 修改告警配置管理
     * 
     * @param alarmConfig 告警配置管理
     * @return 结果
     */
    public int updateAlarmConfig(AlarmConfig alarmConfig);

    /**
     * 删除告警配置管理
     * 
     * @param configId 告警配置管理主键
     * @return 结果
     */
    public int deleteAlarmConfigByConfigId(Long configId);

    /**
     * 批量删除告警配置管理
     * 
     * @param configIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteAlarmConfigByConfigIds(Long[] configIds);
}
